use uuid::Uuid;

use crate::{datatypes::{lenght_prefixed_string::LenghtPrefixedString, varint::VarInt}, packets::{Decode, Encode, Packet}};


pub struct LoginSuccessPacket {
    pub uuid: Uuid,
    pub username: LenghtPrefixedString,
    pub property_length: VarInt,
    // TODO: properties...
}

impl Decode for LoginSuccessPacket {
    fn decode(cursor: &mut std::io::Cursor<&[u8]>) -> anyhow::Result<Self> {
        let uuid = Uuid::decode(cursor)?;
        let username = LenghtPrefixedString::decode(cursor)?;
        let property_length = VarInt::decode(cursor)?;

        Ok(LoginSuccessPacket {
            uuid,
            username,
            property_length
        })
    }
}

impl Encode for LoginSuccessPacket {
    fn encode(&self, buffer: &mut Vec<u8>) -> anyhow::Result<()> {
        self.uuid.encode(buffer)?;
        self.username.encode(buffer)?;
        self.property_length.encode(buffer)?;

        Ok(())
    }
}

impl Packet for LoginSuccessPacket {
    fn get_id(&self) -> i32 {0x02}
}
